@@ -72,14 +72,14 @@ def scatter_2d(x_list, y_list):
     if isinstance(x_list, VariableList):
         x_name = x_list.name
         x_vals = x_list
-    else:
+    elif isinstance(x_list, VariableList2D):
         x_name = x_list.x_name
         x_vals = x_list.x_values
 
     if isinstance(y_list, VariableList):
         y_name = y_list.name
         y_vals = y_vals
-    else:
+    elif isinstance(y_list, VariableList2D):
         y_name = y_list.y_name
         y_vals = y_list.y_values
 
